@@ -2,7 +2,7 @@
 
 const fs = require('fs')
 const os = require('os')
-const fse = require(process.cwd())
+const fse = require('../../')
 const path = require('path')
 const assert = require('assert')
 const copySync = require('../copy-sync')
@@ -28,7 +28,7 @@ describe('copy-sync / broken symlink', () => {
   })
 
   it('should throw an error when dereference=true', () => {
-    assert.throws(() => copySync(src, out, {dereference: true}), err => err.code === 'ENOENT')
+    assert.throws(() => copySync(src, out, { dereference: true }), err => err.code === 'ENOENT')
   })
 })
 
