@@ -24,22 +24,22 @@ describe('+ emptyDir()', () => {
   describe('> when directory exists and contains items', () => {
     it('should delete all of the items', () => {
       // verify nothing
-      assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
       fse.ensureFileSync(path.join(TEST_DIR, 'some-file'))
       fse.ensureFileSync(path.join(TEST_DIR, 'some-file-2'))
       fse.ensureDirSync(path.join(TEST_DIR, 'some-dir'))
-      assert.equal(fs.readdirSync(TEST_DIR).length, 3)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 3)
 
       fse.emptyDirSync(TEST_DIR)
-      assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
     })
   })
 
   describe('> when directory exists and contains no items', () => {
     it('should do nothing', () => {
-      assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
       fse.emptyDirSync(TEST_DIR)
-      assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
     })
   })
 
@@ -48,7 +48,7 @@ describe('+ emptyDir()', () => {
       fse.removeSync(TEST_DIR)
       assert(!fs.existsSync(TEST_DIR))
       fse.emptyDirSync(TEST_DIR)
-      assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
     })
   })
 })
