@@ -79,13 +79,13 @@ describe('fse-ensure-link', () => {
         const dstContent = fs.readFileSync(dstpath, 'utf8')
         const dstDirContents = fs.readdirSync(dstDir)
 
-        assert.equal(isSymlink, true)
-        assert.equal(srcContent, dstContent)
+        assert.strictEqual(isSymlink, true)
+        assert.strictEqual(srcContent, dstContent)
         assert(dstDirContents.indexOf(dstBasename) >= 0)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -96,14 +96,14 @@ describe('fse-ensure-link', () => {
     it(`should return error when creating link file using src ${srcpath} and dst ${dstpath}`, done => {
       const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
       const callback = err => {
-        assert.equal(err instanceof Error, true)
+        assert.strictEqual(err instanceof Error, true)
         // ensure that directories aren't created if there's an error
         const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
-        assert.equal(dstdirExistsBefore, dstdirExistsAfter)
+        assert.strictEqual(dstdirExistsBefore, dstdirExistsAfter)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -116,11 +116,11 @@ describe('fse-ensure-link', () => {
       const callback = err => {
         if (err) return done(err)
         const destinationContentAfter = fs.readFileSync(dstpath, 'utf8')
-        assert.equal(destinationContentBefore, destinationContentAfter)
+        assert.strictEqual(destinationContentBefore, destinationContentAfter)
         return done()
       }
       args.push(callback)
-      return fn.apply(null, args)
+      return fn(...args)
     })
   }
 
@@ -129,15 +129,15 @@ describe('fse-ensure-link', () => {
     const dstpath = args[1]
 
     it(`should create link file using src ${srcpath} and dst ${dstpath}`, () => {
-      fn.apply(null, args)
+      fn(...args)
       const srcContent = fs.readFileSync(srcpath, 'utf8')
       const dstDir = path.dirname(dstpath)
       const dstBasename = path.basename(dstpath)
       const isSymlink = fs.lstatSync(dstpath).isFile()
       const dstContent = fs.readFileSync(dstpath, 'utf8')
       const dstDirContents = fs.readdirSync(dstDir)
-      assert.equal(isSymlink, true)
-      assert.equal(srcContent, dstContent)
+      assert.strictEqual(isSymlink, true)
+      assert.strictEqual(srcContent, dstContent)
       assert(dstDirContents.indexOf(dstBasename) >= 0)
     })
   }
@@ -151,13 +151,13 @@ describe('fse-ensure-link', () => {
       const dstdirExistsBefore = fs.existsSync(path.dirname(dstpath))
       let err = null
       try {
-        fn.apply(null, args)
+        fn(...args)
       } catch (e) {
         err = e
       }
-      assert.equal(err instanceof Error, true)
+      assert.strictEqual(err instanceof Error, true)
       const dstdirExistsAfter = fs.existsSync(path.dirname(dstpath))
-      assert.equal(dstdirExistsBefore, dstdirExistsAfter)
+      assert.strictEqual(dstdirExistsBefore, dstdirExistsAfter)
     })
   }
 
@@ -167,9 +167,9 @@ describe('fse-ensure-link', () => {
 
     it(`should do nothing using src ${srcpath} and dst ${dstpath}`, () => {
       const destinationContentBefore = fs.readFileSync(dstpath, 'utf8')
-      fn.apply(null, args)
+      fn(...args)
       const destinationContentAfter = fs.readFileSync(dstpath, 'utf8')
-      assert.equal(destinationContentBefore, destinationContentAfter)
+      assert.strictEqual(destinationContentBefore, destinationContentAfter)
     })
   }
 
@@ -213,8 +213,8 @@ describe('fse-ensure-link', () => {
             const dstContent = fs.readFileSync(dstpath, 'utf8')
             const dstDirContents = fs.readdirSync(dstDir)
 
-            assert.equal(isSymlink, true)
-            assert.equal(srcContent, dstContent)
+            assert.strictEqual(isSymlink, true)
+            assert.strictEqual(srcContent, dstContent)
             assert(dstDirContents.indexOf(dstBasename) >= 0)
           })
       })
