@@ -4,13 +4,13 @@ const assert = require('assert')
 const path = require('path')
 const crypto = require('crypto')
 const os = require('os')
-const semver = require('semver')
+const atLeastNode = require('at-least-node')
 const fs = require('../..')
 
 const SIZE = 1000
 
-// Used for tests on Node 7.2.0+ only
-const onNode7it = semver.gte(process.version, '7.2.0') ? it : it.skip
+// Used for tests on Node 12.9.0+ only
+const describeNode12 = atLeastNode('12.9.0') ? describe : describe.skip
 
 describe('fs.read()', () => {
   let TEST_FILE
@@ -100,7 +100,7 @@ describe('fs.write()', () => {
         })
     })
 
-    onNode7it('returns an object when minimal arguments are passed', () => {
+    it('returns an object when minimal arguments are passed', () => {
       return fs.write(TEST_FD, TEST_DATA)
         .then(results => {
           const bytesWritten = results.bytesWritten
@@ -132,7 +132,7 @@ describe('fs.write()', () => {
       })
     })
 
-    onNode7it('works when minimal arguments are passed', done => {
+    it('works when minimal arguments are passed', done => {
       fs.write(TEST_FD, TEST_DATA, (err, bytesWritten, buffer) => {
         assert.ifError(err)
         assert.strictEqual(bytesWritten, SIZE, 'bytesWritten is correct')
@@ -152,3 +152,59 @@ describe('fs.write()', () => {
     })
   })
 })
+
+describeNode12('fs.writev()', () => {
+  let TEST_FILE
+  let TEST_DATA
+  let TEST_FD
+
+  beforeEach(() => {
+    TEST_FILE = path.join(os.tmpdir(), 'fs-extra', 'writev-test-file')
+    TEST_DATA = [crypto.randomBytes(SIZE / 2), crypto.randomBytes(SIZE / 2)]
+    fs.ensureDirSync(path.dirname(TEST_FILE))
+    TEST_FD = fs.openSync(TEST_FILE, 'w')
+  })
+
+  afterEach(() => {
+    return fs.close(TEST_FD)
+      .then(() => fs.remove(TEST_FILE))
+  })
+
+  describe('with promises', () => {
+    it('returns an object', () => {
+      return fs.writev(TEST_FD, TEST_DATA, 0)
+        .then(({ bytesWritten, buffers }) => {
+          assert.strictEqual(bytesWritten, SIZE, 'bytesWritten is correct')
+          assert.deepStrictEqual(buffers, TEST_DATA, 'data is correct')
+        })
+    })
+
+    it('returns an object when minimal arguments are passed', () => {
+      return fs.writev(TEST_FD, TEST_DATA)
+        .then(({ bytesWritten, buffers }) => {
+          assert.strictEqual(bytesWritten, SIZE, 'bytesWritten is correct')
+          assert.deepStrictEqual(buffers, TEST_DATA, 'data is correct')
+        })
+    })
+  })
+
+  describe('with callbacks', () => {
+    it('works', done => {
+      fs.writev(TEST_FD, TEST_DATA, 0, (err, bytesWritten, buffers) => {
+        assert.ifError(err)
+        assert.strictEqual(bytesWritten, SIZE, 'bytesWritten is correct')
+        assert.deepStrictEqual(buffers, TEST_DATA, 'data is correct')
+        done()
+      })
+    })
+
+    it('works when minimal arguments are passed', done => {
+      fs.writev(TEST_FD, TEST_DATA, (err, bytesWritten, buffers) => {
+        assert.ifError(err)
+        assert.strictEqual(bytesWritten, SIZE, 'bytesWritten is correct')
+        assert.deepStrictEqual(buffers, TEST_DATA, 'data is correct')
+        done()
+      })
+    })
+  })
+})
