@@ -5,7 +5,6 @@ const os = require('os')
 const fse = require(process.cwd())
 const path = require('path')
 const assert = require('assert')
-const outputJsonSync = require('../output-json-sync')
 
 /* global beforeEach, describe, it */
 
@@ -23,7 +22,7 @@ describe('json', () => {
       assert(!fs.existsSync(file))
 
       const data = { name: 'JP' }
-      outputJsonSync(file, data)
+      fse.outputJsonSync(file, data)
 
       assert(fs.existsSync(file))
       const newData = JSON.parse(fs.readFileSync(file, 'utf8'))
@@ -39,7 +38,7 @@ describe('json', () => {
         const replacer = (k, v) => v === 'JP' ? 'Jon Paul' : v
         const data = { name: 'JP' }
 
-        outputJsonSync(file, data, { replacer })
+        fse.outputJsonSync(file, data, { replacer })
         const newData = JSON.parse(fs.readFileSync(file, 'utf8'))
 
         assert.strictEqual(newData.name, 'Jon Paul')
