@@ -8,8 +8,6 @@ const assert = require('assert')
 
 /* global before, describe, it */
 
-const o755 = parseInt('755', 8)
-
 describe('mkdirp / clobber', () => {
   let TEST_DIR
   let file
@@ -19,7 +17,7 @@ describe('mkdirp / clobber', () => {
     fse.emptyDir(TEST_DIR, err => {
       assert.ifError(err)
 
-      const ps = [ TEST_DIR ]
+      const ps = [TEST_DIR]
 
       for (let i = 0; i < 15; i++) {
         const dir = Math.floor(Math.random() * Math.pow(16, 4)).toString(16)
@@ -42,13 +40,9 @@ describe('mkdirp / clobber', () => {
   })
 
   it('should clobber', done => {
-    fse.mkdirp(file, o755, err => {
+    fse.mkdirp(file, 0o755, err => {
       assert.ok(err)
-      if (os.platform().indexOf('win') === 0) {
-        assert.strictEqual(err.code, 'EEXIST')
-      } else {
-        assert.strictEqual(err.code, 'ENOTDIR')
-      }
+      assert.strictEqual(err.code, 'ENOTDIR')
       done()
     })
   })
