@@ -53,27 +53,27 @@ describe('+ moveSync() - prevent moving into itself', () => {
   })
 
   describe('> when source is a file', () => {
-    it(`should move the file successfully even when dest parent is 'src/dest'`, () => {
+    it("should move the file successfully even when dest parent is 'src/dest'", () => {
       const destFile = path.join(TEST_DIR, 'src', 'dest', 'destfile.txt')
       return testSuccessFile(src, destFile)
     })
 
-    it(`should move the file successfully when dest parent is 'src/src_dest'`, () => {
+    it("should move the file successfully when dest parent is 'src/src_dest'", () => {
       const destFile = path.join(TEST_DIR, 'src', 'src_dest', 'destfile.txt')
       return testSuccessFile(src, destFile)
     })
 
-    it(`should move the file successfully when dest parent is 'src/dest_src'`, () => {
+    it("should move the file successfully when dest parent is 'src/dest_src'", () => {
       const destFile = path.join(TEST_DIR, 'src', 'dest_src', 'destfile.txt')
       return testSuccessFile(src, destFile)
     })
 
-    it(`should move the file successfully when dest parent is 'src/dest/src'`, () => {
+    it("should move the file successfully when dest parent is 'src/dest/src'", () => {
       const destFile = path.join(TEST_DIR, 'src', 'dest', 'src', 'destfile.txt')
       return testSuccessFile(src, destFile)
     })
 
-    it(`should move the file successfully when dest parent is 'srcsrc/dest'`, () => {
+    it("should move the file successfully when dest parent is 'srcsrc/dest'", () => {
       const destFile = path.join(TEST_DIR, 'srcsrc', 'dest', 'destfile.txt')
       return testSuccessFile(src, destFile)
     })
@@ -81,59 +81,59 @@ describe('+ moveSync() - prevent moving into itself', () => {
 
   describe('> when source is a directory', () => {
     describe('>> when dest is a directory', () => {
-      it(`of not itself`, () => {
+      it('of not itself', () => {
         const dest = path.join(TEST_DIR, src.replace(/^\w:/, ''))
         return testSuccessDir(src, dest)
       })
-      it(`of itself`, () => {
+      it('of itself', () => {
         const dest = path.join(src, 'dest')
         return testError(src, dest)
       })
-      it(`should move the directory successfully when dest is 'src_dest'`, () => {
+      it("should move the directory successfully when dest is 'src_dest'", () => {
         const dest = path.join(TEST_DIR, 'src_dest')
         return testSuccessDir(src, dest)
       })
-      it(`should move the directory successfully when dest is 'src-dest'`, () => {
+      it("should move the directory successfully when dest is 'src-dest'", () => {
         const dest = path.join(TEST_DIR, 'src-dest')
         return testSuccessDir(src, dest)
       })
 
-      it(`should move the directory successfully when dest is 'dest_src'`, () => {
+      it("should move the directory successfully when dest is 'dest_src'", () => {
         const dest = path.join(TEST_DIR, 'dest_src')
         return testSuccessDir(src, dest)
       })
 
-      it(`should move the directory successfully when dest is 'src_dest/src'`, () => {
+      it("should move the directory successfully when dest is 'src_dest/src'", () => {
         const dest = path.join(TEST_DIR, 'src_dest', 'src')
         return testSuccessDir(src, dest)
       })
 
-      it(`should move the directory successfully when dest is 'src-dest/src'`, () => {
+      it("should move the directory successfully when dest is 'src-dest/src'", () => {
         const dest = path.join(TEST_DIR, 'src-dest', 'src')
         return testSuccessDir(src, dest)
       })
 
-      it(`should move the directory successfully when dest is 'dest_src/src'`, () => {
+      it("should move the directory successfully when dest is 'dest_src/src'", () => {
         const dest = path.join(TEST_DIR, 'dest_src', 'src')
         return testSuccessDir(src, dest)
       })
 
-      it(`should move the directory successfully when dest is 'src_src/dest'`, () => {
+      it("should move the directory successfully when dest is 'src_src/dest'", () => {
         const dest = path.join(TEST_DIR, 'src_src', 'dest')
         return testSuccessDir(src, dest)
       })
 
-      it(`should move the directory successfully when dest is 'src-src/dest'`, () => {
+      it("should move the directory successfully when dest is 'src-src/dest'", () => {
         const dest = path.join(TEST_DIR, 'src-src', 'dest')
         return testSuccessDir(src, dest)
       })
 
-      it(`should move the directory successfully when dest is 'srcsrc/dest'`, () => {
+      it("should move the directory successfully when dest is 'srcsrc/dest'", () => {
         const dest = path.join(TEST_DIR, 'srcsrc', 'dest')
         return testSuccessDir(src, dest)
       })
 
-      it(`should move the directory successfully when dest is 'dest/src'`, () => {
+      it("should move the directory successfully when dest is 'dest/src'", () => {
         const dest = path.join(TEST_DIR, 'dest', 'src')
         return testSuccessDir(src, dest)
       })
@@ -145,22 +145,22 @@ describe('+ moveSync() - prevent moving into itself', () => {
         return testSuccessDir(src, dest)
       })
 
-      it(`should error when dest is 'src/dest'`, () => {
+      it("should error when dest is 'src/dest'", () => {
         const dest = path.join(TEST_DIR, 'src', 'dest')
         return testError(src, dest)
       })
 
-      it(`should error when dest is 'src/src_dest'`, () => {
+      it("should error when dest is 'src/src_dest'", () => {
         const dest = path.join(TEST_DIR, 'src', 'src_dest')
         return testError(src, dest)
       })
 
-      it(`should error when dest is 'src/dest_src'`, () => {
+      it("should error when dest is 'src/dest_src'", () => {
         const dest = path.join(TEST_DIR, 'src', 'dest_src')
         return testError(src, dest)
       })
 
-      it(`should error when dest is 'src/dest/src'`, () => {
+      it("should error when dest is 'src/dest/src'", () => {
         const dest = path.join(TEST_DIR, 'src', 'dest', 'src')
         return testError(src, dest)
       })
@@ -299,7 +299,7 @@ describe('+ moveSync() - prevent moving into itself', () => {
         }
       })
 
-      it(`should move the directory successfully when dest is 'src_src/dest'`, () => {
+      it("should move the directory successfully when dest is 'src_src/dest'", () => {
         const srcLink = path.join(TEST_DIR, 'src-symlink')
         fs.symlinkSync(src, srcLink, 'dir')
 
@@ -309,7 +309,7 @@ describe('+ moveSync() - prevent moving into itself', () => {
         assert.strictEqual(link, src)
       })
 
-      it(`should move the directory successfully when dest is 'srcsrc/dest'`, () => {
+      it("should move the directory successfully when dest is 'srcsrc/dest'", () => {
         const srcLink = path.join(TEST_DIR, 'src-symlink')
         fs.symlinkSync(src, srcLink, 'dir')
 
