@@ -19,7 +19,7 @@ describe('remove / async / dir', () => {
   describe('> when dir does not exist', () => {
     it('should not throw an error', done => {
       const someDir = path.join(TEST_DIR, 'some-dir/')
-      assert.equal(fs.existsSync(someDir), false)
+      assert.strictEqual(fs.existsSync(someDir), false)
       fse.remove(someDir, err => {
         assert.ifError(err)
         done()
