@@ -70,11 +70,12 @@ describe('remove', () => {
       fs.writeFileSync(file, 'hello')
 
       assert(fs.existsSync(file))
-      const existsChecker = setInterval(() => {
+      let existsChecker = setInterval(() => {
         fse.pathExists(file, (err, itDoes) => {
           assert.ifError(err)
-          if (!itDoes) {
+          if (!itDoes && existsChecker) {
             clearInterval(existsChecker)
+            existsChecker = null
             done()
           }
         })
